PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Util/FancyLock.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Macros
FancyLock.hpp File Reference
`#include <mutex>`

Go to the source code of this file.

## Data Structures
struct | fancy_lock_guard

## Macros
#define | WITH_LOCKGUARD(m)

## Macro Definition Documentation

## ◆ WITH_LOCKGUARD

#define WITH_LOCKGUARD | ( |  | m | ) |

Value:
if (auto __lock = fancy_lock_guard(m))
fancy_lock_guard
Definition FancyLock.hpp:9